function love.load()
  background = {}
  background.color = {math.random(), math.random(), math.random()}
  background.timeElapsed = 0
  background.timeToChange = 5
  -- Create an empty table to store the balloons
  balloons = {}
  -- Create a score variable
  score = 0
  -- Create a game over variable
  gameOver = false
  -- Create a timer variable
  timer = 60
end

function love.update(dt)
  background.timeElapsed = background.timeElapsed + dt
  if background.timeElapsed > background.timeToChange then
    background.color = {math.random(), math.random(), math.random()}
    background.timeElapsed = 0
  end
  if not gameOver then
    timer = timer - dt
    -- Iterate over all the balloons
    for i, balloon in ipairs(balloons) do
      -- Move the balloon up the screen
      balloon.y = balloon.y - dt * 100
      -- If the balloon reaches the top of the screen, remove it from the table
      if balloon.y < 0 then
        table.remove(balloons, i)
      end
    end
    -- Create a new balloon randomly
    if math.random() < 0.01 then
      local newBalloon = {
        x = math.random(0, love.graphics.getWidth() - 50),
        y = love.graphics.getHeight(),
        width = math.random(20, 50),
        height = math.random(20, 50),
        color = {math.random(), math.random(), math.random()}
      }
      table.insert(balloons, newBalloon)
    end
    -- Check if the timer is less than 0 and set the game over variable to true
    if timer < 0 then
      gameOver = true
    end
  end
end

function love.mousepressed(x, y, button, isTouch)
    if button == 1 then
        for i, balloon in ipairs(balloons) do
            if x > balloon.x and x < balloon.x + balloon.width and y > balloon.y and y < balloon.y + balloon.height then
              table.remove(balloons, i)
              score = score + 1
              break
            end
        end
    end
end
function love.draw()
  love.graphics.setColor(background.color)
  love.graphics.rectangle("fill", 0, 0, love.graphics.getWidth(), love.graphics.getHeight())
  for _, balloon in ipairs(balloons) do
    love.graphics.setColor(balloon.color)
    love.graphics.circle("fill", balloon.x + balloon.width/2, balloon.y + balloon.height/2, balloon.width/2, 50)
    love.graphics.setColor(1, 1, 1)
    love.graphics.circle("line", balloon.x + balloon.width/2, balloon.y + balloon.height/2, balloon.width/2, 50)
    love.graphics.line(balloon.x + balloon.width/2, balloon.y + balloon.height/2, balloon.x + balloon.width/2, balloon.y + balloon.height + 20)
  end
  if gameOver then
    love.graphics.print("Game Over", love.graphics.getWidth() / 2 - 50, love.graphics.getHeight() / 2 - 20)
    love.graphics.print("Score: " .. score, love.graphics.getWidth() / 2 - 50, love.graphics.getHeight() / 2)
  else
    love.graphics.print("Score: "..score, 10, 10)
  end
end
